/*
 * Include file for trackedit drivers.  See drivers.c for full details.
 *
 */
#ifndef _DRIVERS_H
#define _DRIVERS_H

#include <audiofile.h>

/* ======================================================================== */
/* Output driver types */
enum Drivertype {
  drvOSSDSP,
  drvFILE,
};

/* Structures with details pertaining to specific output drivers */
typedef struct Driver_ossdsp {
  char *device;
  int fd;
  int bufsize;
} Driver_ossdsp;

typedef struct Driver_file {
  char *filename;
  AFfilehandle fh;
  int file_format;
  int sample_format;
} Driver_file;

/* A structure containing details of an output driver.  Between an open() */
/* and close(), total_written keeps a running total of frames sent to the */
/* driver via write().  After close(), total_written is the total number  */
/* of frames written between open() and close(). */
typedef struct _Driver Driver;
struct _Driver {
  int type;
  int sample_rate, n_channels;
  int sample_size;
  int active;
  int total_written;
  union {
    Driver_ossdsp ossdsp;
    Driver_file file;
  } dev;
  int (*configure)(Driver *, int, int, int);
  int (*open)(Driver *);
  int (*get_buffer_size)(Driver *);
  int (*write)(Driver *, char *, int);
  int (*close)(Driver *);
  int (*free)(Driver *);
};

/* ======================================================================== */

/* From drivers.c */
Driver *driver_new(int type);
int driver_configure(Driver *d, int sample_rate, int n_channels, int sample_size);
int driver_open(Driver *d);
int driver_get_buffer_size(Driver *d);
int driver_write(Driver *d, char *buf, int size);
int driver_close(Driver *d);
int driver_free(Driver *d);

/* ======================================================================== */

#endif
