/*
 * Trackedit - a small, simple program to explore an audio file and split
 * it up as desired.
 *
 */

#include <stdio.h>
#include <stdlib.h>
#include <audiofile.h>

#include "trackedit.h"
#include "version.h"

#define PROGNAME "trackedit"

/* ======================================================================== */

void show_usage() {
/*
 * Displays a short message giving help with program usage.
 *
 */
  fprintf(stderr,PROGNAME " version " VERSION "\n"
    "Explore an audio file and optionally split it into smaller files.\n"
    "(c) 2002 Jonathan Woithe.  Released under the terms of the GNU General Public\n"
    "License - no warranty is given or implied.  See source for full details.\n"
    "Usage: " PROGNAME " [<options>] [<input file>]\n"
    "Available options:\n"
    " -h        Display this help message and exit\n"
    " -v        Show program version and exit\n"
  );
}
/* ======================================================================== */

int parse_args(int argc, char *argv[], Options *options) {
/*
 * Parse command line arguments into fields of the Options structure.
 *
 */
int i=1;
int err=0;
  while (!err && i<argc) {
    if (argv[i][0]!='-') {
      /* A filename is specified */
      if (options->init_inputfile==NULL)
        options->init_inputfile = argv[i];
      else {
        err=1;
        fprintf(stderr,PROGNAME ": only one input file can be specified.\n");
      }
    } else
    if (argv[i][0]=='-' && strlen(argv[i])==2) {
      /* Toggle option */
      switch (argv[i][1]) {
        case 'h': show_usage(); return(0); break;
        case 'v':
          fprintf(stderr,PROGNAME " version " VERSION ".\n");
          return(0);
          break;
        default: err=1;
      }
    } else
    if (argv[i][0]=='-' && strlen(argv[i])>3 && argv[i][2]=='=') {
      /* Value option */
      switch (argv[i][1]) {
        default: err=1;
      }
    } else {
      err=1;
    }
    i++;
  }
  if (err) {
    fprintf(stderr,PROGNAME ": error in parameter `%s'\n",argv[i-1]);
    show_usage();
  }
  return(!err);
}
/* ======================================================================== */

void print_file_info (char *filename) {
/*
 * Prints some helpful information about the given (audio) file.
 *
 */
}
/* ======================================================================== */

int main (int argc, char *argv[]) {

Options options = {init_inputfile: NULL};

  /* Parse command line arguments; exit if there's an error. */
  if (parse_args(argc,argv,&options)!=1) {
    return(1);
  }

  if_text(&options);
  return(0);

#if 0
char *outfilename;
int format = AF_FILE_UNKNOWN;

AFfilehandle outfile;
AFfilesetup outfilesetup;
int sampleFormat, sampleWidth, channelCount;
char *buffer;

AFframecount FrameCount;
int frameSize;
          
	outfilesetup = afNewFileSetup();
	afInitFileFormat(outfilesetup, format);
	afInitChannels(outfilesetup, AF_DEFAULT_TRACK, channelCount);
	afInitSampleFormat(outfilesetup, AF_DEFAULT_TRACK, sampleFormat,
		sampleWidth);

	outfile = afOpenFile(outfilename, "w", outfilesetup);
	if (outfile == AF_NULL_FILEHANDLE)
	{
		printf("Could not open file '%s' for writing.\n", outfilename);
		return 1;
	}

	afFreeFileSetup(outfilesetup);

	afWriteFrames(outfile, AF_DEFAULT_TRACK, buffer, frameCount);
	afCloseFile(outfile);
#endif

  return 0;
}
