/*
 * Include file for trackedit.  See trackedit.c for full details.
 *
 */
#ifndef _TRACKEDIT_H
#define _TRACKEDIT_H

#include <audiofile.h>

#include "drivers.h"

/* ======================================================================== */
/* Track editor state information */
typedef struct Trackeditor {
  AFfilehandle input;
  char *input_filename;
  AFframecount frame_count;
  int file_format;
  int sample_rate;
  int channel_count, frame_size;
  int sample_size, sample_count;
  char *buf;
  int start_frame, end_frame;
  int fadein_frames, fadeout_frames;
  float fsd;
  Driver *output;
} Trackeditor;

/* Program options */
typedef struct Options {
  char *init_inputfile;
} Options;

/* ======================================================================== */
/* Externally visible routines */

/* drivers.c routines in drivers.h */

/* From if_*.c */
int if_text();

/* From trackedit.c */
Trackeditor *trackeditor_new();
void trackeditor_free(Trackeditor *te);
int trackeditor_get_frame_position(Trackeditor *te);
int trackeditor_get_frames_of_time(Trackeditor *te, float sec);
float trackeditor_get_time_of_frames(Trackeditor *te, int nframes);
int trackeditor_set_frame_position(Trackeditor *te, int frame);
int trackeditor_set_input_file(Trackeditor *te, char *name);
int trackeditor_set_output(Trackeditor *te, Driver *d);
int trackeditor_close_input_file(Trackeditor *te);
int trackeditor_set_play_options(Trackeditor *te, int start_frame, 
  int end_frame, float fadein_time, float fadeout_time);
int trackeditor_play(Trackeditor *te, float ofs, float duration);
int trackeditor_stopplay(Trackeditor *te);
      
/* ======================================================================== */

#endif
